@@ -7,16 +7,16 @@
 /* Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -47,6 +47,9 @@ namespace Gtk
  */
 struct BuiltinStockID
 {
+  /**
+   * The text representation of the stock id, usually something like "gtk-about".
+   */
   const char* id;
 };
 
@@ -69,6 +72,7 @@ extern GTKMM_API const Gtk::BuiltinStockID ADD;              /*!< @image html gt
 extern GTKMM_API const Gtk::BuiltinStockID APPLY;            /*!< @image html gtk-apply.png               */
 extern GTKMM_API const Gtk::BuiltinStockID BOLD;             /*!< @image html gtk-bold.png           */
 extern GTKMM_API const Gtk::BuiltinStockID CANCEL;           /*!< @image html gtk-cancel.png              */
+extern GTKMM_API const Gtk::BuiltinStockID CAPS_LOCK_WARNING; /*!< @image html gtk-caps-lock-warning.png  */
 extern GTKMM_API const Gtk::BuiltinStockID CDROM;            /*!< @image html gtk-cdrom.png               */
 extern GTKMM_API const Gtk::BuiltinStockID CLEAR;            /*!< @image html gtk-clear.png               */
 extern GTKMM_API const Gtk::BuiltinStockID CLOSE;            /*!< @image html gtk-close.png               */
@@ -177,14 +181,43 @@ extern GTKMM_API const Gtk::BuiltinStockID ZOOM_FIT;         /*!< @image html gt
 extern GTKMM_API const Gtk::BuiltinStockID ZOOM_IN;          /*!< @image html gtk-zoom-in.png             */
 extern GTKMM_API const Gtk::BuiltinStockID ZOOM_OUT;         /*!< @image html gtk-zoom-out.png            */
 
-
+/** Add a stock item to the list of registered stock items.
+ * @param item StockItem to register.
+ * 
+ * If an item already exists with the same stock ID the old item gets replaced. 
+ */
 void add(const Gtk::StockItem& item);
 
+/** Fills item with the registered values for stock_id.
+  * @param stock_id StockID to search for.
+  * @param item item to fill in case stockid was found.
+  *
+  * @return <tt>true</tt> if the item was found - <tt>false</tt> otherwise.
+  */
 bool lookup(const Gtk::StockID& stock_id, Gtk::StockItem& item);
-bool lookup(const Gtk::StockID& stock_id, Gtk::IconSet& iconset);
+
+/** See IconSet::lookup_default()
+  * @param stock_id StockID to search for.
+  * @param iconset to fill.
+  *
+  * @return <tt>true</tt> if the item was found - <tt>false</tt> otherwise.
+  */
+bool lookup(const Gtk::StockID& stock_id, Glib::RefPtr<Gtk::IconSet>& iconset);
+
+/** Receive an Image of the registered stock id with the correct size.
+  * @param stock_id StockID to search for.
+  * @param size: IconSize of the desired Image.
+  * @param image: Image to fill.
+  *
+  * @return <tt>true</tt> if the item was found - <tt>false</tt> otherwise
+  */  
 bool lookup(const Gtk::StockID& stock_id, Gtk::IconSize size, Gtk::Image& image);
 
-Glib::SListHandle<Gtk::StockID,Gtk::StockID_Traits> get_ids();
+/** Retrieves a list of all known stock IDs added to an IconFactory or registered with Stock::add().
+  *
+  * @return list of all known stock IDs.
+  */
+std::vector<Gtk::StockID> get_ids();
 
 } // namespace Stock
 
