@@ -1,5 +1,5 @@
 #include <gtkmm.h>
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 #include <iostream>
 #include <list>
 
@@ -29,7 +29,7 @@ MyWindow::MyWindow()
 {
   set_size_request(200, 200);
 
-  m_Button.signal_clicked().connect( SigC::slot(*this, &MyWindow::on_button_clicked) );
+  m_Button.signal_clicked().connect( sigc::mem_fun(*this, &MyWindow::on_button_clicked) );
   m_Box.pack_start(m_Button);
   add(m_Box);
 }
@@ -42,9 +42,9 @@ void MyWindow::on_button_clicked()
     std::cout << "After d.run()" << std::endl;
   }
 
-   std::cout << "before list_toplevel" << std::endl;
-  std::list<Gtk::Window*> toplevelwindows = list_toplevels();
-   std::cout << "after list_toplevel" << std::endl;
+  std::cout << "before list_toplevel" << std::endl;
+  std::vector<Gtk::Window*> toplevelwindows = list_toplevels();
+  std::cout << "after list_toplevel" << std::endl;
 
   std::cout << "toplevelwindows.size = " << toplevelwindows.size() << std::endl;
 }
