@@ -62,6 +62,10 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_ACTIVATABLE )
             << get_defs( GTK_TYPE_ADJUSTMENT )
             << get_defs( GTK_TYPE_ALIGNMENT)
+            << get_defs( GTK_TYPE_APP_CHOOSER )
+            << get_defs( GTK_TYPE_APP_CHOOSER_BUTTON )
+            << get_defs( GTK_TYPE_APP_CHOOSER_DIALOG )
+            << get_defs( GTK_TYPE_APP_CHOOSER_WIDGET )
             << get_defs( GTK_TYPE_APPLICATION )
             << get_defs( GTK_TYPE_ARROW )
             << get_defs( GTK_TYPE_ASPECT_FRAME )
